Author: jfthomps
Date: Tue Sep 14 19:27:29 2010
New Revision: 997053

URL: http://svn.apache.org/viewvc?rev=997053&view=rev
Log:
renamed vmprofile.nasshare to vmprofile.repositorypath

utils.php: modified getVMProfiles

vm.php:
-modified editVMInfo
-modified AJupdateVMprofileItem

vm.js:
-modified VMHostDataCB
-modified getVMprofileDataCB
-modified delProfile

Modified:
    incubator/vcl/trunk/web/.ht-inc/utils.php
    incubator/vcl/trunk/web/.ht-inc/vm.php
    incubator/vcl/trunk/web/js/vm.js

Modified: incubator/vcl/trunk/web/.ht-inc/utils.php
URL: 
http://svn.apache.org/viewvc/incubator/vcl/trunk/web/.ht-inc/utils.php?rev=997053&r1=997052&r2=997053&view=diff
==============================================================================
--- incubator/vcl/trunk/web/.ht-inc/vm.php (original)
+++ incubator/vcl/trunk/web/.ht-inc/vm.php Tue Sep 14 19:27:29 2010
@@ -214,8 +214,8 @@ function editVMInfo() {
        print "    <td><span id=pimage dojoType=\"dijit.form.FilteringSelect\" 
searchAttr=\"name\" onchange=\"updateProfile('pimage', 'imageid');\" 
style=\"width: 420px\"></span></td>\n";
        print "  </tr>\n";
        print "  <tr>\n";
-       print "    <th align=right>NAS Share:</th>\n";
-       print "    <td><span id=pnasshare dojoType=\"dijit.InlineEditBox\" 
onChange=\"updateProfile('pnasshare', 'nasshare');\"></span></td>\n";
+       print "    <th align=right>Repository Path:</th>\n";
+       print "    <td><span id=prepositorypath 
dojoType=\"dijit.InlineEditBox\" onChange=\"updateProfile('prepositorypath', 
'repositorypath');\"></span></td>\n";
        print "  </tr>\n";
        print "  <tr>\n";
        print "    <th align=right>Data Store Path:</th>\n";
@@ -795,7 +795,7 @@ function AJupdateVMprofileItem() {
        }
        $profileid = processInputVar('profileid', ARG_NUMERIC);
        $item = processInputVar('item', ARG_STRING);
-       if(! 
preg_match('/^(profilename|vmtypeid|imageid|nasshare|datastorepath|vmpath|virtualswitch0|virtualswitch1|vmdisk|username|password|vmware_mac_eth0_generated|vmware_mac_eth1_generated)$/',
 $item)) {
+       if(! 
preg_match('/^(profilename|vmtypeid|imageid|repositorypath|datastorepath|vmpath|virtualswitch0|virtualswitch1|vmdisk|username|password|vmware_mac_eth0_generated|vmware_mac_eth1_generated)$/',
 $item)) {
                print "alert('Invalid data submitted.');";
                return;
        }

Modified: incubator/vcl/trunk/web/js/vm.js
URL: 
http://svn.apache.org/viewvc/incubator/vcl/trunk/web/js/vm.js?rev=997053&r1=997052&r2=997053&view=diff
==============================================================================
--- incubator/vcl/trunk/web/js/vm.js (original)
+++ incubator/vcl/trunk/web/js/vm.js Tue Sep 14 19:27:29 2010
@@ -77,7 +77,7 @@ function VMHostDataCB(data, ioArgs) {
        var ct = '<table>';
        ct += '<tr><th align=right>VM type:</th><td>' + profile.type + 
'</td></tr>';
        ct += '<tr><th align=right>Image:</th><td>' + profile.image + 
'</td></tr>';
-       ct += '<tr><th align=right>NAS Share:</th><td>' + profile.nasshare + 
'</td></tr>';
+       ct += '<tr><th align=right>Repository Path:</th><td>' + 
profile.repositorypath + '</td></tr>';
        ct += '<tr><th align=right>Datastore Path:</th><td>' + 
profile.datastorepath + '</td></tr>';
        ct += '<tr><th align=right>VM Path:</th><td>' + profile.vmpath + 
'</td>';
        ct += '<tr><th align=right>Virtual Switch 0:</th><td>' + 
profile.virtualswitch0 + '</td></tr>';
@@ -576,7 +576,7 @@ function getVMprofileDataCB(data, ioArgs
                obj.setValue(curprofile.vmdisk);
 
        dijit.byId('pname').noValueIndicator = '(empty)';
-       dijit.byId('pnasshare').noValueIndicator = '(empty)';
+       dijit.byId('prepositorypath').noValueIndicator = '(empty)';
        dijit.byId('pdspath').noValueIndicator = '(empty)';
        dijit.byId('pvmpath').noValueIndicator = '(empty)';
        dijit.byId('pvs0').noValueIndicator = '(empty)';
@@ -584,7 +584,7 @@ function getVMprofileDataCB(data, ioArgs
        dijit.byId('pusername').noValueIndicator = '(empty)';
 
        dijit.byId('pname').setValue(curprofile.profilename);
-       dijit.byId('pnasshare').setValue(curprofile.nasshare);
+       dijit.byId('prepositorypath').setValue(curprofile.repositorypath);
        dijit.byId('pdspath').setValue(curprofile.datastorepath);
        dijit.byId('pvmpath').setValue(curprofile.vmpath);
        dijit.byId('pvs0').setValue(curprofile.virtualswitch0);
@@ -659,8 +659,8 @@ function delProfile(cont) {
        content += "<td>" + curprofile.image + "</td>";
        content += "</tr>";
        content += "<tr>";
-       content += "<th align=right>NAS Share:</th>";
-       content += "<td>" + curprofile.nasshare + "</td>";
+       content += "<th align=right>Repository Path:</th>";
+       content += "<td>" + curprofile.repositorypath + "</td>";
        content += "</tr>";
        content += "<tr>";
        content += "<th align=right>Data Store Path:</th>";


Reply via email to
--- incubator/vcl/trunk/web/.ht-inc/utils.php (original)
+++ incubator/vcl/trunk/web/.ht-inc/utils.php Tue Sep 14 19:27:29 2010
@@ -7773,7 +7773,7 @@ function generateString($length=8) {
 /// \b typeid - id of vm type\n
 /// \b image - name of image used for this profile\n
 /// \b imageid - id of image used for this profile\n
 /// \b nasshare - share exported by nas to the vmhost\n
 /// \b datastorepath - path to where vm data files are stored\n
 /// \b vmpath - path to where vm configuration files are stored\n
 /// \b virtualswitch0 - name of first virtual switch\n
@@ -7793,7 +7793,7 @@ function getVMProfiles($id="") {
               .        "vp.vmtypeid, "
               .        "i.prettyname AS image, "
               .        "vp.imageid, "
-              .        "vp.nasshare, "
+              .        "vp.repositorypath, "
               .        "vp.datastorepath, "
               .        "vp.vmpath, "
               .        "vp.virtualswitch0, "
@@ -7773,7 +7773,7 @@ function generateString($length=8) {
 /// \b image - name of image used for this profile\n
 /// \b imageid - id of image used for this profile\n
-/// \b nasshare - share exported by nas to the vmhost\n
+/// \b repositorypath - share exported by nas to the vmhost\n
 /// \b datastorepath - path to where vm data files are stored\n
 /// \b vmpath - path to where vm configuration files are stored\n

Modified: incubator/vcl/trunk/web/.ht-inc/vm.php
URL: 
http://svn.apache.org/viewvc/incubator/vcl/trunk/web/.ht-inc/vm.php?rev=997053&r1=997052&r2=997053&view=diff
==============================================================================